"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mwsBuild = mwsBuild;
exports.mwsDevServer = mwsDevServer;
exports.mwsDLL = mwsDLL;

var tslib_1 = _interopRequireWildcard(require("tslib"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _mwBuild = _interopRequireDefault(require("./mwBuild"));

var _mwBabelOptions = _interopRequireDefault(require("./mwBabelOptions"));

var _mwPostCSSOptions = _interopRequireDefault(require("./mwPostCSSOptions"));

var _mwTSOptions = _interopRequireDefault(require("./mwTSOptions"));

var _mwDevServer = _interopRequireDefault(require("./mwDevServer"));

var _mwMultiEntryHTML = _interopRequireDefault(require("./mwMultiEntryHTML"));

var _mwPlugins = _interopRequireDefault(require("./mwPlugins"));

var _mwRules = _interopRequireDefault(require("./mwRules"));

var _mwENV = _interopRequireDefault(require("./mwENV"));

var _mwDLL = _interopRequireDefault(require("./mwDLL"));

var _mwPWA = _interopRequireDefault(require("./mwPWA"));

function noop() {
  return tslib_1.__awaiter(this, void 0, void 0, function () {
    return tslib_1.__generator(this, function (_a) {
      return [2];
    });
  });
}

function getCustomConfig(cwd, config) {
  if ('function' === typeof config) {
    return config;
  }

  var paths = [];

  switch (process.env.NODE_ENV) {
    case 'production':
      paths.push.apply(paths, ['build', 'production', 'prod']);
      break;

    case 'development':
      paths.push.apply(paths, ['development', 'develop', 'dev']);
      break;

    case 'beta':
      paths.push.apply(paths, ['beta', 'build', 'production', 'prod', 'development', 'develop', 'dev']);
      break;

    default:
      paths.push(process.env.NODE_ENV);
      break;
  }

  paths.push('config');
  paths = paths.map(function (name) {
    return "webpack." + name + ".js";
  });
  config && paths.unshift(config);
  var cc = noop;
  var i = -1;

  while (++i < paths.length) {
    var p = paths[i];

    var pp = _path.default.join(cwd, p);

    if (_fs.default.existsSync(pp)) {
      console.log(">>> " + pp);
      cc = require(pp);
      break;
    }
  }

  return cc;
}

function mwsBuild(cwd, config) {
  var mwConfig = getCustomConfig(cwd, config);
  return [_mwENV.default, _mwBuild.default, _mwPWA.default, _mwMultiEntryHTML.default, _mwDLL.default, _mwPlugins.default, _mwRules.default, _mwBabelOptions.default, _mwPostCSSOptions.default, _mwTSOptions.default, mwConfig];
}

function mwsDevServer(cwd, config) {
  var mwConfig = getCustomConfig(cwd, config);
  return [_mwENV.default, _mwBuild.default, _mwPWA.default, _mwMultiEntryHTML.default, _mwDLL.default, _mwPlugins.default, _mwRules.default, _mwBabelOptions.default, _mwPostCSSOptions.default, _mwTSOptions.default, _mwDevServer.default, mwConfig];
}

function mwsDLL(cwd, config) {
  var mwConfig = getCustomConfig(cwd, config);
  return [_mwENV.default, _mwBuild.default, _mwDLL.default, _mwPlugins.default, _mwRules.default, _mwBabelOptions.default, _mwPostCSSOptions.default, _mwTSOptions.default, mwConfig];
}